@@ -1,13 +1,13 @@
 package Search::Elasticsearch::Async;
 
-use Search::Elasticsearch 5.00;
+our $VERSION = '5.02';
+use Search::Elasticsearch 5.02;
 use Promises 0.93 ();
 use parent 'Search::Elasticsearch';
 
 use Search::Elasticsearch::Util qw(parse_params);
 use namespace::clean;
 
-our $VERSION = '5.00';
 
 #===================================
 sub new {
@@ -47,7 +47,7 @@ Search::Elasticsearch::Async - Async API for Elasticsearch using Promises
 
 =head1 VERSION
 
-version 5.00
+version 5.02
 
 =head1 SYNOPSIS
 
@@ -122,7 +122,7 @@ version 5.00
 =head1 DESCRIPTION
 
 L<Search::Elasticsearch::Async> is the official B<asynchronous> Perl client for
-Elasticsearch, supported by L<elasticsearch.com|http://www.elasticsearch.com>.
+Elasticsearch, supported by L<elastic.co|http://elastic.co>.
 Elasticsearch itself is a flexible and powerful open source, distributed real-time
 search and analytics engine for the cloud.  You can read more about it
 on L<elastic.co|http://www.elastic.co>.
@@ -646,7 +646,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2017 by Elasticsearch BV.
 
 This is free software, licensed under:
 
