@@ -1,7 +1,7 @@
 package Search::Elasticsearch::Client::5_0::Async;
 
-our $VERSION='5.00';
-use Search::Elasticsearch::Client::5_0 5.00 ();
+our $VERSION='5.02';
+use Search::Elasticsearch::Client::5_0 5.02 ();
 
 1;
 
@@ -15,7 +15,7 @@ Search::Elasticsearch::Client::5_0::Async - Thin async client with full support
 
 =head1 VERSION
 
-version 5.00
+version 5.02
 
 =head1 DESCRIPTION
 
@@ -27,7 +27,7 @@ with L<Search::Elasticsearch::Async> as follows:
         client => "5_0::Direct"
     );
 
-See C<Search::Elasticsearch::Client::5_0::Direct> for documentation
+See L<Search::Elasticsearch::Client::5_0::Direct> for documentation
 about how to use the client itself.
 
 =head1 PREVIOUS VERSIONS OF ELASTICSEARCH
@@ -60,7 +60,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2017 by Elasticsearch BV.
 
 This is free software, licensed under:
 
