@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Client::5_0::Async::Bulk;
-$Search::Elasticsearch::Client::5_0::Async::Bulk::VERSION = '5.00';
+$Search::Elasticsearch::Client::5_0::Async::Bulk::VERSION = '5.02';
 use Moo;
 with 'Search::Elasticsearch::Client::5_0::Role::Bulk',
     'Search::Elasticsearch::Role::Is_Async';
@@ -127,7 +127,7 @@ Search::Elasticsearch::Client::5_0::Async::Bulk - A helper module for the Bulk A
 
 =head1 VERSION
 
-version 5.00
+version 5.02
 
 =head1 SYNOPSIS
 
@@ -405,8 +405,8 @@ See the individual helper methods below for details.
 B<Note:> Parameters like C<index> or C<type> can be specified as C<index> or as
 C<_index>, so the following two lines are equivalent:
 
-    index => { index  => 'index', type  => 'type', id  => 1, source  => {...}},
-    index => { _index => 'index', _type => 'type', _id => 1, _source => {...}},
+    index => { index  => 'index', type  => 'type', id  => 1, source => {...}},
+    index => { _index => 'index', _type => 'type', _id => 1, source => {...}},
 
 B<Note:> The C<index> and C<type> parameters can be specified in the
 params for any action, but if not specified, will default to the C<index>
@@ -498,7 +498,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2017 by Elasticsearch BV.
 
 This is free software, licensed under:
 
